@@ -12,6 +12,10 @@
 
 #ifdef HAVE_FORK
 
+#ifdef SOLARIS
+#include <sys/loadavg.h>
+#endif
+
 #include "sock.h"
 
 #define MINCORES 1
@@ -59,8 +63,12 @@ Extern void SUFFIX(cubafork)(Spin **pspin)
     static int load = uninitialized;
     if( load == uninitialized ) {
       double loadavg;
-      getloadavg(&loadavg, 1);
-      load = floor(loadavg);
+      int ret_code = getloadavg(&loadavg, 1);
+      if (ret_code < 0) {
+	*pspin = NULL;
+	return;
+      }
+      load = floor(loadavg);      
     }
     cubaworkers_.ncores = IMax(-cubaworkers_.ncores - load, 0);
   }
@@ -142,7 +150,7 @@ Extern void SUFFIX(cubawait)(Spin **pspin)
 
   for( core = 0; core < cores; ++core ) {
     DEB_ONLY(pid_t pid;)
-    MASTER("waiting for child");
+    MASTER("waiting for child", (pid_t) 0);
     DEB_ONLY(pid =) wait(&status);
     MASTER("pid %d terminated with exit code %d", pid, status);
   }
